# Graph Data Extractor (GDE)

GDE is a simple tool that lets you overlay axes on a raster image (e.g. a jpeg from a figure), click on some data points, and then extract them as CSV.
More sophisticated alternative tools are available!

GDE was originally part of [Myokit](https://github.com/MichaelClerx/myokit), but is now maintained as a separate project.

## Install

`pip install gde`

## Usage

To run, simply type `gde`, or `python3 -m gde`.

- To load a file, use `gde gui file.gde`.
- To install shortcuts and register file types: `gde icons`
- For more options, try `gde --help`


